/**
 * Creates an object wrapper.
 * @syntax new Object( [ value ] )
 * @param {String} value Any value.
 * @returns {Object} 
 */
function Object( ) {
}
/**
 * Tests for an object in another object's prototype chain.
 * @syntax prototype.isPrototypeOf(object)
 * @param {Object} prototype   an object to be tested against each link in the prototype chain of the object  argument
 * @param {Object} object the object whose prototype chain will be searched
 * @returns {Boolean} 
 */
Object.prototype.isPrototypeOf = function(object) {};

/**
 * Returns a string representing the source code of the object.
 * @syntax obj.toSource()
 * @returns {String} 
 */
Object.prototype.toSource = function() {};

/**
 * Returns a string representing the object. This method is meant to be overriden by derived objects for locale-specific purposes.
 * @syntax toLocaleString()
 * @returns {String} 
 */
Object.prototype.toLocaleString = function() {};

/**
 * Defines new or modifies existing properties directly on an object, returning the object.
 * @syntax Object.defineProperties(obj, props)
 * @param {Object} obj The object on which to define or modify properties.
 * @param {Object} props An object whose own enumerable properties constitute descriptors for the properties to be defined or modified.
 * @returns {undefined} 
 * @static
 */
Object.defineProperties = function(obj,  props) {};

/**
 * Removes a watchpoint set with the watch() method.
 * @syntax unwatch(prop)
 * @param {String} prop The name of a property of the object to stop watching.
 * @returns {undefined} 
 */
Object.prototype.unwatch = function(prop) {};

/**
 * @syntax Object.getOwnPropertyDescriptor(obj, prop)
 * @param {Object} obj The object in which to look for the property.
 * @param {String} prop The name of the property whose description is to be retrieved
 * @returns {Object} 
 * @static
 */
Object.getOwnPropertyDescriptor = function(obj,  prop) {};

/**
 * Returns the prototype of the specified object.
 * @syntax Object.getPrototypeOf(object)
 * @param {Object} object The object whose prototype is to be returned.
 * @returns {Object} 
 * @static
 */
Object.getPrototypeOf = function(object) {};

/**
 * Seals an object, preventing new properties from being added to it and marking all existing properties as non-configurable. Values of present properties can still be changed as long as they are writable.
 * @syntax Object.seal(obj)
 * @param {Object} obj The object which should be sealed.
 * @returns {Object} 
 * @static
 */
Object.seal = function(obj) {};

/**
 * Returns a Boolean indicating whether the specified property is enumerable.
 * @syntax obj.propertyIsEnumerable(prop)
 * @param {String} prop The name of the property to test.
 * @returns {Boolean} 
 */
Object.prototype.propertyIsEnumerable = function(prop) {};

/**
 * Returns an array of all properties (enumerable or not) found upon a given object.
 * @syntax Object.getOwnPropertyNames(obj)
 * @param {Object} obj The object whose enumerable and non-enumerable own properties are to be returned.
 * @returns {Array} 
 * @static
 */
Object.getOwnPropertyNames = function(obj) {};

/**
 * Returns the primitive value of the specified object
 * @syntax valueOf()
 * @returns {Object} 
 */
Object.prototype.valueOf = function() {};

/**
 * Returns a reference to the Object function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name, but it isn't read only (except for primitive Boolean, Number or String values: 1, true, "read-only").
 * @returns {Function} 
 */
Object.prototype.constructor = new Function();

/**
 * Returns an array of all own enumerable properties found upon a given object, in the same order as that provided by a for-in loop (the difference being that a for-in loop enumerates properties in the prototype chain as well).
 * @syntax Object.keys(obj)
 * @param {Object} obj The object whose enumerable own properties are to be returned.
 * @returns {Array} 
 * @static
 */
Object.keys = function(obj) {};

/**
 * Watches for a property to be assigned a value and runs a function when that occurs.
 * @syntax object.watch(prop, handler)
 * @param {String} prop The name of a property of the object on which you wish to monitor changes.
 * @param {String} handler A function to call when the specified property's value changes.
 * @returns {undefined} 
 */
Object.prototype.watch = function(prop,  handler) {};

/**
 * Evaluates a string of JavaScript code in the context of an object.
 * @syntax object.eval(string)
 * @param {String} string Any string representing a JavaScript expression, statement, or sequence of statements. The expression can include variables and properties of existing objects.
 * @returns {Object} 
 */
Object.prototype.eval = function(string) {};

/**
 * Determine if an object is frozen.
 * @syntax Object.isFrozen(obj)
 * @param {Object} obj The object which should be checked.
 * @returns {Boolean} 
 * @static
 */
Object.isFrozen = function(obj) {};

/**
 * Determines if an object is extensible (whether it can have new properties added to it).
 * @syntax Object.isExtensible(obj)
 * @param {Object} obj The object which should be checked.
 * @returns {Boolean} 
 * @static
 */
Object.isExtensible = function(obj) {};

/**
 * Creates a new object with the specified prototype object and properties.
 * @syntax Object.create(proto [, propertiesObject ])
 * @param {Object} proto The object which should be the prototype of the newly-created object.
 * @param {Object} propertiesObject If specified and not undefined, an object whose enumerable own properties (that is, those properties defined upon itself and not enumerable properties along its prototype chain) specify property descriptors to be added to the newly-created object, with the corresponding property names.
 * @returns {Object} 
 * @static
 */
Object.create = function(proto ) {};

/**
 * Returns a boolean indicating whether the object has the specified property.
 * @syntax obj.hasOwnProperty(prop)
 * @param {String} prop The name of the property to test.
 * @returns {Boolean} 
 */
Object.prototype.hasOwnProperty = function(prop) {};

/**
 * Determine if an object is sealed.
 * @syntax Object.isSealed(obj)
 * @param {Object} obj The object which should be checked.
 * @returns {Boolean} 
 * @static
 */
Object.isSealed = function(obj) {};

/**
 * Freezes an object: that is, prevents new properties from being added to it; prevents existing properties from being removed; and prevents existing properties, or their enumerability, configurability, or writability, from being changed. In essence the object is made effectively immutable. The method returns the object being frozen.
 * @syntax Object.freeze(obj)
 * @param {Object} obj The object to freeze.
 * @returns {Object} 
 * @static
 */
Object.freeze = function(obj) {};

/**
 * Prevents new properties from ever being added to an object (i.e. prevents future extensions to the object).
 * @syntax Object.preventExtensions(obj)
 * @param {Object} obj The object which should be made non-extensible.
 * @returns {Object} 
 * @static
 */
Object.preventExtensions = function(obj) {};

/**
 * Returns a string representing the object.
 * @syntax object.toString()
 * @returns {String} 
 */
Object.prototype.toString = function() {};

/**
 * Defines a new property directly on an object, or modifies an existing property on an object, and returns the object.
 * @syntax Object.defineProperty(obj, prop, descriptor)
 * @param {Object} obj The object on which to define the property.
 * @param {String} prop The name of the property to be defined or modified.
 * @param {String} descriptor The descriptor for the property being defined or modified.
 * @returns {Object} 
 * @static
 */
Object.defineProperty = function(obj,  prop,  descriptor) {};

/**
 * Represents the Object prototype object.
 * @returns {Object} 
 * @static
 */
Object.prototype;

