/**
 * Creates a regular expression object for matching text with a pattern.
 * @syntax RegExp(pattern [, flags])<br> /pattern/flags
 * @param {String} pattern The text of the regular expression.
 * @param {String} flags 
 * @param {String} g global match
 * @param {String} i ignore case
 * @param {String} m Treat beginning and end characters (^ and $) as working over multiple lines (i.e., match the beginning or end of each line (delimited by \n or \r), not only the very beginning or end of the whole input string)
 * @param {String} y New in Firefox 3 Non-standard sticky; matches only from the index indicated by the lastIndex property of this regular expression in the target string (and does not attempt to match from any later indexes). This allows the match-only-at-start capabilities of the character "^" to effectively be used at any location in a string by changing the value of the lastIndex property.
 * @returns {RegExp} 
 */
function RegExp(pattern ) {
}
/**
 * Returns a string representing the source code of the object.
 * @syntax regexp.toSource()
 * @returns {String} 
 */
RegExp.prototype.toSource = function() {};

/**
 * Executes the search for a match between a regular expression and a specified string. Returns true or false.
 * @syntax regexp.test([str])
 * @param {String} str The string against which to match the regular expression.
 * @returns {Boolean} 
 */
RegExp.prototype.test = function() {};

/**
 * Whether or not the "g" flag is used with the regular expression. Read-only JavaScript 1.5: global is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.global = new Boolean();

/**
 * Whether or not the "i" flag is used with the regular expression. JavaScript 1.5: ignoreCase is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.ignoreCase = new Boolean();

/**
 * A read/write integer property that specifies the index at which to start the next match. JavaScript 1.5: lastIndex is a property of a RegExp instance, not the RegExp object.
 * @returns {Number} 
 */
RegExp.prototype.lastIndex = new Number();

/**
 * @returns {Boolean} 
 */
RegExp.prototype.sticky = new Boolean();

/**
 * A read-only property that contains the text of the pattern, excluding the forward slashes. Static JavaScript 1.5: source is a property of a RegExp instance, not the RegExp object.
 * @returns {String} 
 */
RegExp.prototype.source = new String();

/**
 * Reflects whether or not to search in strings across multiple lines. Static JavaScript 1.5: multiline is a property of a RegExp instance, not the RegExp object.
 * @returns {Boolean} 
 */
RegExp.prototype.multiline = new Boolean();

/**
 * The compile() method is used to compile a regular expression during execution of a script. The compile() method can also be used to change and recompile a regular expression.
 * @syntax regExp.compile(regexp, modifier)
 * @param {RegExp} regexp A regular expression
 * @param {String} modifier Specifies the type of matching. "g" for a global match, "i" for a case-insensitive match and "gi" for a global, case-insensitive match
 * @returns {RegExp} 
 */
RegExp.prototype.compile = function(regexp,  modifier) {};

/**
 * Executes a search for a match in a specified string. Returns a result array, or null.
 * @syntax result = regexp.exec(str)
 * @param {String} str The string against which to match the regular expression.
 * @returns {Array} 
 */
RegExp.prototype.exec = function(str) {};

/**
 * Returns a string representing the specified object.
 * @syntax regexp.toString()
 * @returns {String} 
 */
RegExp.prototype.toString = function() {};

/**
 * Returns a reference to the RegExp function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
RegExp.prototype.constructor = new Function();

/**
 * Represents the prototype object for the RegExp constructor.
 * @returns {Object} 
 * @static
 */
RegExp.prototype;

