/**
 * The String global object is a constructor for strings, or a sequence of characters.
 * @syntax String literals take the forms: Or, using the String global object directly:
 * @param {String} thing Anything to be converted to a string.
 * @returns {String} 
 */
function String() {
}
/**
 * Returns a string representing the source code of the object.
 * @syntax string.toSource()
 * @returns {String} 
 */
String.prototype.toSource = function() {};

/**
 * Causes a string to be displayed as a subscript, as if it were in a SUB tag.
 * @syntax sub()
 * @returns {String} 
 */
String.prototype.sub = function() {};

/**
 * Causes a string to be italic, as if it were in an I tag.
 * @syntax italics()
 * @returns {String} 
 */
String.prototype.italics = function() {};

/**
 * Creates an HTML hypertext link that requests another URL.
 * @syntax link(hrefAttribute)
 * @param {String} hrefAttribute Any string that specifies the HREF of the A tag; it should be a valid URL (relative or absolute).
 * @returns {String} 
 */
String.prototype.link = function(hrefAttribute) {};

/**
 * Causes a string to be displayed in the specified color as if it were in a <FONT COLOR="color"> tag.
 * @syntax fontcolor(color)
 * @param {String} color A string expressing the color as a hexadecimal RGB triplet or as a string literal. String literals for color names are listed in the Core JavaScript 1.5 Guide.
 * @returns {String} 
 */
String.prototype.fontcolor = function(color) {};

/**
 * Returns the index within the calling String object of the first occurrence of the specified value, starting the search at fromIndex, returns -1 if the value is not found.
 * @syntax string.indexOf(searchValue[, fromIndex])
 * @param {String} searchValue A string representing the value to search for.
 * @param {Number} fromIndex The location within the calling string to start the search from. It can be any integer between 0 and the length of the string. The default value is 0.
 * @returns {Number} 
 */
String.prototype.indexOf = function(searchValue) {};

/**
 * Causes a string to be displayed as a superscript, as if it were in a SUP tag.
 * @syntax sup()
 * @returns {String} 
 */
String.prototype.sup = function() {};

/**
 * Causes a string to be displayed in fixed-pitch font as if it were in a TT tag.
 * @syntax fixed()
 * @returns {String} 
 */
String.prototype.fixed = function() {};

/**
 * Creates an HTML anchor that is used as a hypertext target.
 * @syntax anchor(nameAttribute)
 * @param {String} nameAttribute A string.
 * @returns {String} 
 */
String.prototype.anchor = function(nameAttribute) {};

/**
 * @syntax string.toUpperCase()
 * @returns {String} 
 */
String.prototype.toUpperCase = function() {};

/**
 * Causes a string to be displayed as struck-out text, as if it were in a STRIKE tag.
 * @syntax strike()
 * @returns {String} 
 */
String.prototype.strike = function() {};

/**
 * Causes a string to be displayed as bold as if it were in a B tag.
 * @syntax bold()
 * @returns {String} 
 */
String.prototype.bold = function() {};

/**
 * Executes the search for a match between a regular expression and this String object.
 * @syntax string.search(regexp)
 * @param {RegExp} regexp A regular expression object. If a non-RegExp object obj is passed, it is implicitly converted to a RegExp by using new RegExp(obj).
 * @returns {Number} 
 */
String.prototype.search = function(regexp) {};

/**
 * @syntax str.quote()
 * @returns {String} 
 */
String.prototype.quote = function() {};

/**
 * Returns a subset of a string between one index and another, or through the end of the string.
 * @syntax string.substring(indexA[, indexB])
 * @param {Number} indexA An integer between 0 and one less than the length of the string.
 * @param {Number} indexB (optional) An integer between 0 and the length of the string.
 * @returns {String} 
 */
String.prototype.substring = function(indexA) {};

/**
 * The length of a string.
 * @returns {Number} 
 */
String.prototype.length = new Number();

/**
 * Returns the primitive value of a String object.
 * @syntax string.valueOf()
 * @returns {String} 
 */
String.prototype.valueOf = function() {};

/**
 * Returns the calling string value converted to upper case, according to any locale-specific case mappings.
 * @syntax toLocaleUpperCase()
 * @returns {String} 
 */
String.prototype.toLocaleUpperCase = function() {};

/**
 * Removes whitespace from both ends of the string.
 * @syntax string.trim()
 * @returns {String} 
 */
String.prototype.trim = function() {};

/**
 * Returns the specified character from a string.
 * @syntax string.charAt(index)
 * @param {Number} index An integer between 0 and 1 less than the length of the string.
 * @returns {String} 
 */
String.prototype.charAt = function(index) {};

/**
 * Returns the characters in a string beginning at the specified location through the specified number of characters.
 * @syntax string.substr(start[, length])
 * @param {Number} start Location at which to begin extracting characters.
 * @param {Number} length The number of characters to extract.
 * @returns {String} 
 */
String.prototype.substr = function(start) {};

/**
 * Returns a reference to the String function that created the instance's prototype. Note that the value of this property is a reference to the function itself, not a string containing the function's name.
 * @returns {Function} 
 */
String.prototype.constructor = new Function();

/**
 * Returns a string created by using the specified sequence of Unicode values.
 * @syntax String.fromCharCode(num1, ..., numN)
 * @param {Number} num1,...,numN A sequence of numbers that are Unicode values.
 * @returns {String} 
 * @static
 */
String.fromCharCode = function(num1) {};

/**
 * Removes whitespace from the left end of the string.
 * @syntax string.trimLeft()
 * @returns {String} 
 */
String.prototype.trimLeft = function() {};

/**
 * Returns a number indicating whether a reference string comes before or after or is the same as the given string in sort order.
 * @syntax localeCompare(compareString)
 * @returns {Number} 
 */
String.prototype.localeCompare = function(compareString) {};

/**
 * Removes whitespace from the right end of the string.
 * @syntax string.trimRight()
 * @returns {String} 
 */
String.prototype.trimRight = function() {};

/**
 * Returns the index within the calling String object of the last occurrence of the specified value, or -1 if not found. The calling string is searched backward, starting at fromIndex.
 * @syntax string.lastIndexOf(searchValue[, fromIndex])
 * @param {String} searchValue A string representing the value to search for.
 * @param {Number} fromIndex The location within the calling string to start the search from, indexed from left to right. It can be any integer between 0 and the length of the string. The default value is the length of the string.
 * @returns {Number} 
 */
String.prototype.lastIndexOf = function(searchValue) {};

/**
 * Returns the calling string value converted to lower case, according to any locale-specific case mappings.
 * @syntax toLocaleLowerCase()
 * @returns {String} 
 */
String.prototype.toLocaleLowerCase = function() {};

/**
 * Combines the text of two or more strings and returns a new string.
 * @syntax string.concat(string2, string3[, ..., stringN])
 * @param {String} string2...stringN Strings to concatenate to this string.
 * @returns {String} 
 */
String.prototype.concat = function(string2,  string3) {};

/**
 * Returns a new string with some or all matches of a pattern replaced by a replacement.  The pattern can be a string or a RegExp, and the replacement can be a string or a function to be called for each match.
 * @syntax newstring = str.replace(regexp|substr, newSubStr|function[, Non-standard flags]);
 * @param {RegExp} regexp A RegExp object. The match is replaced by the return value of parameter #2.
 * @param {String} substr A String that is to be replaced by newSubStr.
 * @param {String} newSubStr The String that replaces the substring received from parameter #1. A number of special replacement patterns are supported; see the "Specifying a string as a parameter" section below.
 * @param {Function} function A function to be invoked to create the new substring (to put in place of the substring received from parameter #1). The arguments supplied to this function are described in the "Specifying a function as a parameter" section below.
 * @param {String} flags Non-standard A string specifying a combination of regular expression flags. The use of the flags parameter in the String.replace method is non-standard, use a RegExp object with the corresponding flags. g global match i ignore case m match over multiple lines y Non-standard sticky
 * @param {String} g global match
 * @param {String} i ignore case
 * @param {String} m match over multiple lines
 * @param {String} y Non-standard
 * @param {String} g global match
 * @param {String} i ignore case
 * @param {String} m match over multiple lines
 * @param {String} y Non-standard
 * @returns {String} 
 */
String.prototype.replace = function(regexp,  newSubStr) {};

/**
 * Causes a string to blink as if it were in a BLINK tag.
 * @syntax blink()
 * @returns {String} 
 */
String.prototype.blink = function() {};

/**
 * Returns the numeric Unicode value of the character at the given index (except for unicode codepoints > 0x10000).
 * @syntax string.charCodeAt(index)
 * @param {Number} index An integer greater than 0 and less than the length of the string; if it is not a number, it defaults to 0.
 * @returns {Number} 
 */
String.prototype.charCodeAt = function(index) {};

/**
 * Returns the calling string value converted to lowercase.
 * @syntax string.toLowerCase()
 * @returns {String} 
 */
String.prototype.toLowerCase = function() {};

/**
 * Extracts a section of a string and returns a new string.
 * @syntax string.slice(beginslice[, endSlice])
 * @param {Number} beginSlice The zero-based index at which to begin extraction.
 * @param {Number} endSlice The zero-based index at which to end extraction. If omitted, slice extracts to the end of the string.
 * @returns {String} 
 */
String.prototype.slice = function(beginslice) {};

/**
 * Splits a String object into an array of strings by separating the string into substrings.
 * @syntax string.split([separator][, limit])
 * @param {String} separator Specifies the character to use for separating the string. The separator is treated as a string or a regular expression. If separator is omitted, the array returned contains one element consisting of the entire string.
 * @param {Number} limit Integer specifying a limit on the number of splits to be found.  The split method still splits on every match of separator, but it truncates the returned array to at most limit elements.
 * @returns {Array} 
 */
String.prototype.split = function() {};

/**
 * Returns a string representing the specified object.
 * @syntax string.toString()
 * @returns {String} 
 */
String.prototype.toString = function() {};

/**
 * Used to retrieve the matches when matching a string against a regular expression.
 * @syntax string.match(regexp)
 * @returns {Array} 
 */
String.prototype.match = function(regexp) {};

/**
 * Causes a string to be displayed in a big font as if it were in a BIG tag.
 * @syntax big()
 * @returns {String} 
 */
String.prototype.big = function() {};

/**
 * Causes a string to be displayed in a small font, as if it were in a SMALL tag.
 * @syntax small()
 * @returns {String} 
 */
String.prototype.small = function() {};

/**
 * Causes a string to be displayed in the specified font size as if it were in a <FONT SIZE="size"> tag.
 * @syntax fontsize(size)
 * @param {Number} size An integer between 1 and 7, a string representing a signed integer between 1 and 7.
 * @returns {Number} 
 */
String.prototype.fontsize = function(size) {};

/**
 * Represents the String prototype object.
 * @returns {Object} 
 * @static
 */
String.prototype;

